@@ -13,15 +13,15 @@
         ValidatedDC, которые используются в аннотациях полей.
 
     @dataclass
-    class TypingValidation(DictReplaceableValidation):
+    class TypingValidation(InstanceValidation):
         Добавляет для использования в аннотациях некоторые алиасы из модуля
         typing, на данный момент это: List, Union, Optional, Any и Literal.
 
     @dataclass
-    class DictReplaceableValidation(BasicValidation):
+    class InstanceValidation(BasicValidation):
         Добавляет возможность при создании экземпляра использовать словарь,
         при инициализации значения поля, вместо экземпляра потомка
-        DictReplaceableValidation указанного в аннотации поля.
+        InstanceValidation указанного в аннотации поля.
         Это может пригодиться, например, при получении json-словаря по апи,
         для автоматической валидации значений.
         Так же, при этом, происходит замена словаря на экземпляр датакласса
@@ -42,7 +42,11 @@ from dataclasses import fields as dataclasses_fields
 from typing import Any, Callable, List, Literal, Optional, Union
 
 
-__version__ = '0.1'
+@dataclass
+class BasicValidationError:
+    value: Any
+    annotation: type
+    exception: Optional[Exception]
 
 
 @dataclass
@@ -68,10 +72,10 @@ class BasicValidation:
         """
         self._run_validation()
 
-    def get_errors(self) -> Optional[list]:
+    def get_errors(self) -> Optional[dict]:
         """
-            Возвращает список с ошибками валидации, или None если
-            валидация данных прошла успешна.
+            Возвращает словарь с ошибками валидации, или None если
+            их нет (то есть - экземпляр валиден).
 
             Можно использовать сразу после создания экземпляра для определения
             его валидности, а так же после вызова метода is_valid(self).
@@ -91,75 +95,79 @@ class BasicValidation:
 
     def _init_validation(self) -> None:
         """
-            Устанавливает свойства используемые при валидации
+            Инициализация валидации
         """
         self._errors = {}
 
-    def _is_instance(self, field_value: Any, field_type: type) -> bool:
+    def _is_instance(self, value: Any, type_: type) -> bool:
         """
             Проверка значения на соответствие типу.
         """
         try:
-            result = isinstance(field_value, field_type)
-
+            result = isinstance(value, type_)
+            exception = None
         except Exception as ex:
-            self.field_exception = ex
+            exception = ex
             result = False
 
         if not result:
-            self.field_errors.append(
-                (field_value, field_type)
+            self._field_errors.append(
+                BasicValidationError(value, type_, exception)
             )
 
         return result
 
-    def _field_validation(self, field: DataclassesField) -> bool:
+    def _init_field_validation(self, field: DataclassesField) -> None:
         """
-            Устанавливает свойства для текущего поля и вызывает проверку.
+            Инициализация валидации для текущего поля
         """
-        self.field_errors = []
-        self.field_exception = None
-        self.field_name = field.name
-        self.field_value = getattr(self, field.name)
-        self.field_type = field.type
+        self._field_errors = []
+        self._field_name = field.name
+        self._field_value = getattr(self, field.name)
+        self._field_type = field.type
 
-        result = self._is_instance(self.field_value, self.field_type)
+    def _is_field_valid(self, field: DataclassesField) -> bool:
+        """
+            Запускает проверку поля
+        """
+        self._init_field_validation(field)
 
-        if not result:
-            # Если проверка поля завершилась неудачно, то добавим список
-            # ошибок поля в ошибки всего экземпляра.
-            errors = {
-                'VALUE': self.field_value,
-                'TYPE': self.field_type
-            }
-            if self.field_exception is not None:
-                errors['EXCEPTION'] = self.field_exception
-            else:
-                errors['ERRORS'] = self.field_errors
+        return self._is_instance(self._field_value, self._field_type)
 
-            self._errors[self.field_name] = errors
-
-        return result
+    def _save_current_field_errors(self) -> None:
+        """
+            Записывает ошибки текущего поля в self._errors
+            (в ошибки всего экземпляра)
+        """
+        self._errors[self._field_name] = self._field_errors
 
     def _run_validation(self) -> None:
         """
-            Запускает валидацию полей
+           Запускает проверку всех полей
         """
         self._init_validation()
 
         for field in dataclasses_fields(self):
-            self._field_validation(field)
+            if not self._is_field_valid(field):
+                self._save_current_field_errors()
 
 
 # ----------------------------------------------------------------------------
 
 
 @dataclass
-class DictReplaceableValidation(BasicValidation):
+class InstanceValidationError:
+    instance_class: type
+    errors: Optional[dict]
+    exception: Optional[Exception]
+
+
+@dataclass
+class InstanceValidation(BasicValidation):
     """
         Добавляет возможность при создании экземпляра использовать словарь,
         при инициализации значения поля, вместо экземпляра потомка
-        DictReplaceableValidation указанного в аннотации поля.
+        InstanceValidation указанного в аннотации поля.
 
         Это может пригодиться, например, при получении json-словаря по апи,
         для автоматической валидации значений.
@@ -167,45 +175,55 @@ class DictReplaceableValidation(BasicValidation):
         Так же, при этом, происходит замена словаря на экземпляр датакласса
         из аннотации (если данные из словаря валидны).
     """
-    def _is_instance(self, field_value: Any, field_type: type) -> bool:
+    def _init_validation(self) -> None:
 
-        if type(field_type) == type and \
-           issubclass(field_type, DictReplaceableValidation):
+        super()._init_validation()
+        # Флаг - выполнять замену словаря на экземпляр класса-потомка
+        # InstanceValidation из аннотации поля (в случае пригодности
+        # словаря для создания такого экземпляра), или Нет.
+        self._replace = True
 
-            if isinstance(field_value, dict) or \
-               isinstance(field_value, field_type):
+    def _is_instance(self, value: Any, type_: type) -> bool:
 
-                if isinstance(field_value, field_type):
-                    value = asdict(field_value)
-                else:
-                    value = field_value
+        is_type = type(type_) == type
+        if is_type and issubclass(type_, InstanceValidation):
 
+            if isinstance(value, dict) or isinstance(value, type_):
+
+                value = asdict(value) if isinstance(value, type_) else value
                 try:
-                    instance = field_type(**value)
+                    exception = None
+                    errors = None
+                    instance = type_(**value)
                     errors = instance.get_errors()
-
                 except Exception as ex:
-                    self.field_exception = ex
-                    errors = []
+                    exception = ex
 
-                if errors is None:
-                    self.replacement = instance
+                if errors is None and exception is None:
+                    self._replacement = instance
                     return True
-
-                elif errors:
-                    self.field_errors.append({instance.__class__: errors})
+                else:
+                    self._field_errors = [
+                        InstanceValidationError(type_, errors, exception)
+                    ]
                     return False
 
-        return super()._is_instance(field_value, field_type)
+        return super()._is_instance(value, type_)
 
-    def _field_validation(self, field: DataclassesField) -> bool:
+    def _init_field_validation(self, field: DataclassesField) -> None:
 
-        self.replacement = False
-        result = super()._field_validation(field)
-        if result and self.replacement:
-            # Если валидация поля прошла успешно и текущее значение у поля
-            # изменилось, то установим новое значение у поля
-            setattr(self, self.field_name, self.replacement)
+        super()._init_field_validation(field)
+        # Свойство для экземпляра предназначенного для замены словаря
+        self._replacement = False
+
+    def _is_field_valid(self, field: DataclassesField) -> bool:
+
+        result = super()._is_field_valid(field)
+
+        # Если включен флаг замены и валидация поля прошла успешно и
+        # есть чем заменять, то установим новое значение у поля
+        if self._replace and result and self._replacement:
+            setattr(self, self._field_name, self._replacement)
 
         return result
 
@@ -224,135 +242,145 @@ STR_ALIASES = {
 
 
 @dataclass
-class TypingValidation(DictReplaceableValidation):
+class ListValidationError:
+    item_number: int
+    item_value: Any
+    annotation: type
+
+
+@dataclass
+class LiteralValidationError:
+    value: Any
+    annotation: type
+
+
+@dataclass
+class TypingValidation(InstanceValidation):
     """
         Добавляет для использования в аннотациях некоторые алиасы из модуля
         typing.
 
         Поддерживаемые алиасы перечислены в константе STR_ALIASES.
     """
-    def _is_instance(self, field_value: Any, field_type: type) -> bool:
+    def _is_instance(self, value: Any, type_: type) -> bool:
 
-        str_field_type = str(field_type)
+        str_type = str(type_)
 
-        if self._is_typing_alias(str_field_type):
+        if self._is_typing_alias(str_type):
 
-            if self._is_supported_alias(str_field_type):
-                is_instance = self._get_alias_method(str_field_type)
-                result = is_instance(field_value, field_type)
-                if result:
-                    return True
-                else:
-                    self.field_errors.append((field_value, field_type))
-                    return False
+            if self._is_supported_alias(str_type):
+                is_instance = self._get_alias_method(str_type)
+                return is_instance(value, type_)
             else:
-                error = '%s - not supported' % str_field_type
+                error = '%s - not supported' % str_type
                 raise Exception(error)
 
-        return super()._is_instance(field_value, field_type)
+        return super()._is_instance(value, type_)
 
     @staticmethod
-    def _is_typing_alias(field_type: str) -> bool:
+    def _is_typing_alias(type_: str) -> bool:
         """
-            Проверяет является ли field_type алиасом из модуля typing
+            Проверяет является ли type_ алиасом из модуля typing
         """
         str_alias = list(STR_ALIASES.values())[0]
         prefix = str_alias[:str_alias.find('.')]
-        return field_type.startswith(prefix)
+        return type_.startswith(prefix)
 
     @staticmethod
-    def _is_supported_alias(field_type: str) -> bool:
+    def _is_supported_alias(type_: str) -> bool:
         """
-            Проверяет является ли field_type поддерживаемым алиасом
+            Проверяет является ли type_ поддерживаемым алиасом
         """
         for str_alias in STR_ALIASES.values():
-            if field_type.startswith(str_alias):
+            if type_.startswith(str_alias):
                 return True
         return False
 
-    def _get_alias_method(self, field_type: str) -> Optional[Callable]:
+    def _get_alias_method(self, type_: str) -> Optional[Callable]:
         """
             Возавращает метод для проверки алиаса
         """
 
-        if field_type.startswith(STR_ALIASES[Union]):
+        if type_.startswith(STR_ALIASES[Union]):
             return self._is_union_instance
 
-        elif field_type.startswith(STR_ALIASES[List]):
+        elif type_.startswith(STR_ALIASES[List]):
             return self._is_list_instance
 
-        elif field_type.startswith(STR_ALIASES[Literal]):
+        elif type_.startswith(STR_ALIASES[Literal]):
             return self._is_literal_instance
 
-        elif field_type.startswith(STR_ALIASES[Any]):
+        elif type_.startswith(STR_ALIASES[Any]):
             return self._is_any_instance
 
-    def _is_union_instance(self, field_value: Any, field_type: type) -> bool:
+    def _is_union_instance(self, value: Any, type_: type) -> bool:
         """
             Валидация на алиасы Optional и Union.
 
-            Проверяет является ли field_value экземпляром одного из типов из
-            кортежа field_type.__args__
+            Проверяет является ли value экземпляром одного из типов из
+            кортежа type_.__args__
         """
         # У Union допустимые типы перечислены в кортеже __args__
-        for item_type in field_type.__args__:
-            if self._is_instance(field_value, item_type):
+        for item_type in type_.__args__:
+            if self._is_instance(value, item_type):
                 return True
-
-        # Нет ни одного типа, подходящего для field_value
+        # Нет ни одного типа, подходящего для value
         return False
 
-    def _is_list_instance(self, field_value: Any, field_type: type) -> bool:
+    def _is_list_instance(self, value: Any, type_: type) -> bool:
         """
             Валидация на алиас List.
 
-            Проверяет является ли field_value списком экземпляров field_type.
+            Проверяет является ли value списком экземпляров type_.
         """
-        if isinstance(field_value, list):
+        if isinstance(value, list):
             # Имеем дело со списком. В родительском классе возможна замена
             # значения-словаря на значение-экземпляр потомка родительского
             # класса. То есть, возможно изменение списка значений текущего
             # поля.
             # Будем к этому готовы.
-            new_field_value = []
+            new_value = []
 
             # У List допустимый тип стоит первым в кортеже __args__
-            field_type = field_type.__args__[0]
-            for item_value in field_value:
-
-                if self._is_instance(item_value, field_type):
+            type_ = type_.__args__[0]
+            for i, item_value in enumerate(value):
+                if self._is_instance(item_value, type_):
                     # Собираем новый список для текущего поля
                     # (так как в нем возможна замена элемента-словаря на
                     # элемент-экземпляр потомка родительского класса)
-                    if self.replacement:
-                        value = self.replacement
-                        self.replacement = False
-                    else:
-                        value = item_value
-
-                    new_field_value.append(value)
-
+                    if self._replacement:
+                        item_value = self._replacement
+                        self._replacement = False
+                    new_value.append(item_value)
                 else:
+                    self._field_errors.append(
+                        ListValidationError(i, item_value, type_)
+                    )
                     return False
 
-            # Все элементы списка field_value валидные.
-            self.replacement = new_field_value
-
+            # Все элементы списка value валидные.
+            self._replacement = new_value
             return True
-
         else:
             # Значение поля - не список, а это ошибка валидации
             return False
 
-    def _is_literal_instance(self, field_value: Any, field_type: type) -> bool:
+    def _is_literal_instance(self, value: Any, type_: type) -> bool:
         """
             Валидация на алиас Literal.
 
-            Проверяет является ли field_value одним из field_type.__args__
+            Проверяет является ли value одним из type_.__args__
         """
-        return field_value in field_type.__args__
+        result = value in type_.__args__
 
-    def _is_any_instance(self, field_value: Any, field_type: type) -> bool:
+        if not result:
+            self._field_errors.append(
+                LiteralValidationError(value, type_)
+            )
+
+        return result
+
+    def _is_any_instance(self, value: Any, type_: type) -> bool:
         """
             Валидация на алиас Any.
 
@@ -391,7 +419,6 @@ class ValidatedDC(TypingValidation):
                         get_field_validated_dc(item, set_validated_dc)
             elif type(annotation) == type and \
                     issubclass(annotation, ValidatedDC):
-
                 set_validated_dc.add(annotation)
 
             return set_validated_dc
